==> imuikit-1.0.4.20171101-3-sources.jar: com/xdja/im/uikit/utils/DataConvertUtils.java <==
package com.xdja.im.uikit.utils;

import android.text.TextUtils;

import com.xdja.im.core.model.message.file.FileInfo;
import com.xdja.im.core.model.message.file.ImageFileInfo;
import com.xdja.im.core.model.message.file.VideoFileInfo;
import com.xdja.im.lib.album.bean.ImageThumbBean;
import com.xdja.im.lib.camera.bean.PhotoThumbBean;
import com.xdja.im.lib.file.bean.FileItem;
import com.xdja.im.lib.video.bean.VideoItem;
import com.xdja.im.uikit.utils.log.LogUtil;

/**
 * @Package: com.xdja.im.core.utils
 * @Author: xdjaxa
 * @Creation: 2017-05-02 14:53
 * @Version V1.0
 * @Description:数据工具类
 */
public class DataConvertUtils {

    /**
     * 图片信息转换
     *
     * @param thumbBean
     * @return
     */
    public static FileInfo mapImageFileInfo(ImageThumbBean thumbBean) {

        ImageFileInfo imageFileInfo = new ImageFileInfo();
        if (TextUtils.isEmpty(thumbBean.getThumbPath()) ||
                TextUtils.isEmpty(thumbBean.getHdThumbPath())) {
            LogUtil.e("ERROR:thumb path is empty or hd thumb path is null.");
            return null;
        }
        //缩略图
        imageFileInfo.setFileName(thumbBean.getThumbName());
        imageFileInfo.setFilePath(thumbBean.getThumbPath());
        imageFileInfo.setFileSize(thumbBean.getThumbSize());

        //高清缩略图
        FileInfo hdThumbFile = new FileInfo();
        hdThumbFile.setFileName(thumbBean.getHdThumbName());
        hdThumbFile.setFilePath(thumbBean.getHdThumbPath());
        hdThumbFile.setFileSize(thumbBean.getHdThumbSize());
        imageFileInfo.setHdFileInfo(hdThumbFile);

        //原图
        if (!TextUtils.isEmpty(thumbBean.getRawPath())) {
            FileInfo rawFileInfo = new FileInfo();
            rawFileInfo.setFileName(thumbBean.getRawName());
            rawFileInfo.setFilePath(thumbBean.getRawPath());
            rawFileInfo.setFileSize(thumbBean.getRawSize());
            imageFileInfo.setRawFileInfo(rawFileInfo);
            imageFileInfo.setOriginal(true);
        }
        return imageFileInfo;
    }

    /**
     * 小视频信息转化
     *
     * @param videoItem
     * @return
     */
    public static FileInfo mapVideoFileInfo(VideoItem videoItem) {
        if (TextUtils.isEmpty(videoItem.getFilePath()) ||
                TextUtils.isEmpty(videoItem.getRawFilePath())) {
            LogUtil.e("ERROR: video file path is null.");
            return null;
        }

        VideoFileInfo videoFileInfo = new VideoFileInfo();
        //缩略图文件
        videoFileInfo.setFileName(videoItem.getFileName());
        videoFileInfo.setFilePath(videoItem.getFilePath());
        videoFileInfo.setFileSize(videoItem.getFileSize());

        //视频源文件
        FileInfo rawFileInfo = new FileInfo();
        rawFileInfo.setFileName(videoItem.getRawFileName());
        rawFileInfo.setFilePath(videoItem.getRawFilePath());
        rawFileInfo.setFileSize(videoItem.getRawFileSize());
        videoFileInfo.setRawFileInfo(rawFileInfo);

        videoFileInfo.setAmountOfTime(videoItem.getDuration());
        videoFileInfo.setRawFileSize(videoItem.getRawFileSize());
        return videoFileInfo;
    }

    public static FileInfo mapPhotoFileInfo(PhotoThumbBean thumbBean) {
        ImageFileInfo imageFileInfo = new ImageFileInfo();
        if (TextUtils.isEmpty(thumbBean.getThumbPath()) ||
                TextUtils.isEmpty(thumbBean.getHdThumbPath())) {
            LogUtil.e("ERROR:thumb path is im_uikit_empty or hd thumb path is null.");
            return null;
        }
        //缩略图
        imageFileInfo.setFileName(thumbBean.getThumbName());
        imageFileInfo.setFilePath(thumbBean.getThumbPath());
        imageFileInfo.setFileSize(thumbBean.getThumbSize());

        //高清缩略图
        FileInfo hdThumbFile = new FileInfo();
        hdThumbFile.setFileName(thumbBean.getHdThumbName());
        hdThumbFile.setFilePath(thumbBean.getHdThumbPath());
        hdThumbFile.setFileSize(thumbBean.getHdThumbSize());
        imageFileInfo.setHdFileInfo(hdThumbFile);

        //原图
        if (!TextUtils.isEmpty(thumbBean.getRawPath())) {
            FileInfo rawFileInfo = new FileInfo();
            rawFileInfo.setFileName(thumbBean.getRawName());
            rawFileInfo.setFilePath(thumbBean.getRawPath());
            rawFileInfo.setFileSize(thumbBean.getRawSize());
            imageFileInfo.setRawFileInfo(rawFileInfo);
            imageFileInfo.setOriginal(true);
        }
        return imageFileInfo;
    }

    /**
     * 文件信息转化
     *
     * @param fileItem
     * @return
     */
    public static FileInfo mapFileInfo(FileItem fileItem) {
        if (TextUtils.isEmpty(fileItem.getFilePath())) {
            LogUtil.e("ERROR: file path is null.");
            return null;
        }
        FileInfo fileInfo = new FileInfo();
        fileInfo.setFileName(fileItem.getFileName());
        fileInfo.setFilePath(fileItem.getFilePath());
        fileInfo.setFileSize(fileItem.getFileSize());
        return fileInfo;
    }
}

==> imuikit-1.0.5.20171220_5-sources.jar: com/xdja/im/uikit/utils/DataConvertUtils.java <==
package com.xdja.im.uikit.utils;

import android.text.TextUtils;

import com.xdja.im.core.model.message.file.FileInfo;
import com.xdja.im.core.model.message.file.ImageFileInfo;
import com.xdja.im.core.model.message.file.VideoFileInfo;
import com.xdja.im.lib.album.bean.ImageThumbBean;
import com.xdja.im.lib.camera.bean.PhotoThumbBean;
import com.xdja.im.lib.file.bean.FileItem;
import com.xdja.im.lib.filemanage.util.ToolUtil;
import com.xdja.im.lib.video.bean.VideoItem;
import com.xdja.im.uikit.utils.log.LogUtil;

/**
 * @Package: com.xdja.im.core.utils
 * @Author: xdjaxa
 * @Creation: 2017-05-02 14:53
 * @Version V1.0
 * @Description:数据工具类
 */
public class DataConvertUtils {

    /**
     * 图片信息转换
     *
     * @param thumbBean
     * @return
     */
    public static FileInfo mapImageFileInfo(ImageThumbBean thumbBean) {

        ImageFileInfo imageFileInfo = new ImageFileInfo();
        if (TextUtils.isEmpty(thumbBean.getThumbPath()) ||
                TextUtils.isEmpty(thumbBean.getHdThumbPath())) {
            LogUtil.e("ERROR:thumb path is empty or hd thumb path is null.");
            return null;
        }
        //缩略图
        imageFileInfo.setFileName(thumbBean.getThumbName());
        imageFileInfo.setFilePath(thumbBean.getThumbPath());
        imageFileInfo.setFileSize(thumbBean.getThumbSize());

        //高清缩略图
        FileInfo hdThumbFile = new FileInfo();
        hdThumbFile.setFileName(thumbBean.getHdThumbName());
        hdThumbFile.setFilePath(thumbBean.getHdThumbPath());
        hdThumbFile.setFileSize(thumbBean.getHdThumbSize());
        imageFileInfo.setHdFileInfo(hdThumbFile);

        //原图
        if (!TextUtils.isEmpty(thumbBean.getRawPath())) {
            FileInfo rawFileInfo = new FileInfo();
            rawFileInfo.setFileName(thumbBean.getRawName());
            rawFileInfo.setFilePath(thumbBean.getRawPath());
            rawFileInfo.setFileSize(thumbBean.getRawSize());
            imageFileInfo.setRawFileInfo(rawFileInfo);
            imageFileInfo.setOriginal(true);
        }
        return imageFileInfo;
    }

    /**
     * 小视频信息转化
     *
     * @param videoItem
     * @return
     */
    public static FileInfo mapVideoFileInfo(VideoItem videoItem) {
        if (TextUtils.isEmpty(videoItem.getFilePath()) ||
                TextUtils.isEmpty(videoItem.getRawFilePath())) {
            LogUtil.e("ERROR: video file path is null.");
            return null;
        }

        VideoFileInfo videoFileInfo = new VideoFileInfo();
        //缩略图文件
        videoFileInfo.setFileName(videoItem.getFileName());
        videoFileInfo.setFilePath(videoItem.getFilePath());
        videoFileInfo.setFileSize(videoItem.getFileSize());

        //视频源文件
        FileInfo rawFileInfo = new FileInfo();
        rawFileInfo.setFileName(videoItem.getRawFileName());
        rawFileInfo.setFilePath(videoItem.getRawFilePath());
        rawFileInfo.setFileSize(videoItem.getRawFileSize());
        videoFileInfo.setRawFileInfo(rawFileInfo);

        videoFileInfo.setAmountOfTime(videoItem.getDuration());
        videoFileInfo.setRawFileSize(videoItem.getRawFileSize());
        return videoFileInfo;
    }

    public static FileInfo mapPhotoFileInfo(PhotoThumbBean thumbBean) {
        ImageFileInfo imageFileInfo = new ImageFileInfo();
        if (TextUtils.isEmpty(thumbBean.getThumbPath()) ||
                TextUtils.isEmpty(thumbBean.getHdThumbPath())) {
            LogUtil.e("ERROR:thumb path is im_uikit_empty or hd thumb path is null.");
            return null;
        }
        //缩略图
        imageFileInfo.setFileName(thumbBean.getThumbName());
        imageFileInfo.setFilePath(thumbBean.getThumbPath());
        imageFileInfo.setFileSize(thumbBean.getThumbSize());

        //高清缩略图
        FileInfo hdThumbFile = new FileInfo();
        hdThumbFile.setFileName(thumbBean.getHdThumbName());
        hdThumbFile.setFilePath(thumbBean.getHdThumbPath());
        hdThumbFile.setFileSize(thumbBean.getHdThumbSize());
        imageFileInfo.setHdFileInfo(hdThumbFile);

        //原图
        if (!TextUtils.isEmpty(thumbBean.getRawPath())) {
            FileInfo rawFileInfo = new FileInfo();
            rawFileInfo.setFileName(thumbBean.getRawName());
            rawFileInfo.setFilePath(thumbBean.getRawPath());
            rawFileInfo.setFileSize(thumbBean.getRawSize());
            imageFileInfo.setRawFileInfo(rawFileInfo);
            imageFileInfo.setOriginal(true);
        }
        return imageFileInfo;
    }

    /**
     * 文件信息转化
     *
     * @param fileItem
     * @return
     */
    public static FileInfo mapFileInfo(FileItem fileItem) {
        if (TextUtils.isEmpty(fileItem.getFilePath())) {
            LogUtil.e("ERROR: file path is null.");
            return null;
        }
        FileInfo fileInfo = new FileInfo();
        fileInfo.setFileName(fileItem.getFileName());
        fileInfo.setFilePath(fileItem.getFilePath());
        fileInfo.setFileSize(fileItem.getFileSize());

        String suffix = ToolUtil.getLastString(fileItem.getFileName(), ".");
        if(!TextUtils.isEmpty(suffix)){
            fileInfo.setSuffix(suffix);
        }
        return fileInfo;
    }

}
